--[[
This file is used for adding custom bars to SquawkAndAwe, so you can track
buffs that SAA doesn't officially support. Things should work out properly, but
I give no guarantees that adding 700 spells to track will go by without a hitch.

Adding custom spells is a three-step process. The first is the easiest: Decide
which category you want the spell tracked by. There are five categories - 

Trinkets: Self-explanatory, this is where trinkets go. Not really supported, as
	there have been major errors for some people that I've never tracked down.
	If it works for you, then go ahead and add new trinkets here. If not, use...

Procs: These are buffs that occur on yourself without activation. SAA provides 
	support for tracking duration and internal cooldown, if it exists, as well 
	as flashing the bar and providing a sound reminder when the proc occurs.

Debuffs: These are debuffs that appear on your opponent, for which you are the 
	source (sorry, not gonna let you try and turn Squawk into Utopia =P). 
	Support for Faerie Fire from any source is a rather special case.
	
CC: Crowd-control. Very similar to debuff support, with the addition of checking
	your focus as well as your target. Note that it wil only track one target at
	a time, preferring your current target over your focus.

Abilities: Spells you cast which have a cooldown. Activated trinkets would go
	here instead of Procs if you don't want to put them in Trinkets. SAA 
	supports display of both cooldown and duration (either duration of the buff
	it provides on you, or a forced-length duration such as for Force of Nature)
	
--------------------------------------------------------------------------------	
	
Step Two: Now that you've decided which category to add your spell to, you need
	to provide SAA with information about the spell. Copy one of the following
	structures into SquawkAndAwe:LoadCustomBars() at the end of this file, then
	edit it to match the spell you're trying to track. Editing instructions are
	provided in the comments for each structure

IDs: Most of what SAA does is based on the id of the spell you're tracking. For 
	abilities, cc, and debuffs, this is pretty simple. Find any rank of the 
	spell in Wowhead, and use the number listed in the URL of the spell. Procs 
	and trinkets can be a little more tricky. 
	
	Take, for example, Heroic Charred Twilight Scale. Searching for it on 
	Wowhead leads to http://www.wowhead.com/item=54588 . This means that the 
	item id is 54588 (SAA needs this, too, for trinkets). Hovering your mouse 
	over the tooltip text "Equip: Your damaging spells have a chance to grant 
	861 spell power for 15 sec." shows that this is a link. Clicking it brings 
	you to http://www.wowhead.com/spell=75474 , and you might think that this is
	the spell id that SAA needs. 
	
	It's not. When you equip HCTScale, 75474 is the spell that is cast on you to
	enable the proc. Note that, for talent-based procs, searching for the talent 
	will get you to a similar spell, the one that is cast on you when you take 
	the talent.We're looking for the spell of the proc itself. Look in the
	Spell Details section, and you'll see that the Effect of this spell is 
	"Apply Aura: Proc Trigger Spell". This is the best clue you have that this 
	isn't the right spell. It also shows you the right spell, because directly 
	under that is the icon for, and a link to, Twilight Flames 
	(http://www.wowhead.com/spell=75473). This is the spell that SAA needs to 
	track, and its id is 75473. See the example given inside LoadCustomBars()
	for instructions on how to complete the data structures for Heroic Charred
	Twilight Scale. 
	
	Also shown is an example for tracking Owlkin Frenzy. Searching for Owlkin 
	Frenzy will get you to spell 48389, spell 48391, or spell 48392; one for 
	each rank, each with a different chance to proc. All of these spells link 
	you to spell 48391, which is the buff you gain when OF procs.
	
Colors: Colors are listed as r = red, g = green, b = blue, a = alpha. Best way
	to get a color you like is to change the color of a different bar, log out,
	then check the information for the bar you changed in the savedvariables 
	file for SAA.
	
	
-- Trinkets
SquawkAndAwe.combat.trinkets.flare	= {			-- Obviously change 'flare' to a name that fits your trinket
	id			= 64713,						-- spellid of the buff you get. See above
	itemid		= 45518,						-- itemid of the trinket.
	name		= GetSpellInfo(64713), 			-- copy the id above into the parentheses
	itemname	= GetItemInfo(45518),			-- copy the itemid above into the parentheses
	color 		= {r=1, g=0.8, b=0.32, a=0.9},	-- Color. See above.
	cd 			= 45,							-- If the trinket has an ICD, list it here in seconds. DO NOT list the cooldown of an activated trinket.
	shortname	= "Flare"}						-- Shortened name field. Add this if you don't want the whole name of the trinket displayed,
												it can be anything you want.

-- Procs
SquawkAndAwe.combat.procs.Omen	= {		-- Again, change the name to fit your spell
	id = 16870,							-- spell id
	name = GetSpellInfo(16870),			-- copy the spell id into the parentheses.
	cd	= 10}							-- Optional (and just for show, as Omen has no cooldown)

-- Debuffs
SquawkAndAwe.combat.debuffs.Moonfire	= {		-- Yup, you guessed it.
	id = 48463,									-- spell id.
	name = GetSpellInfo(48463),					-- Copy id between the parentheses
	tick = 3}									-- Time between ticks, in seconds
	
-- CC
SquawkAndAwe.combat.cc.Roots	= {		-- All of this is the same as Procs
	id = 339,	
	name = GetSpellInfo(339)}

Abilities
SquawkAndAwe.combat.abilities.Force	= {	
	id = 33831,
	name = GetSpellInfo(33831),
	dur = 30}							-- Duration of the spell, if it's not a buff on yourself and you want it tracked.

--------------------------------------------------------------------------------	
	
Step Three: Now that you've told SAA about the spell you want tracked, you need 
	to tell it how you want that information displayed. Here you'll define
	things that would normally be configured through the Options Dialogue. 
	Unfortunately that's not possible without a major rewrite, so if you want 
	to change things you'll have to change them here, then reload the addon.
	Trinkets don't have a Step Three.
	
Sounds: A little more involved than you'd think. Since we can't change these 
	in-game, your best bet is to change the sound for a non-custom spell, then
	look in the savedvariables file for SAA and copy the sound name from there. 
	Same idea as colors.
	
Procs:
SquawkAndAwe.defaults.char.bars.procs.Omen	= {	-- This MUST match the name you chose in Step Two EXACTLY.
					show	= true,				-- Probably best to leave this as true (otherwise, why are you adding it?)
					color	= {r=0.6, g=0.6, b=1, a=0.9},	-- Same as the color field for trinkets in Step Two.
					sound	= "None",			-- See note above
					flash   = false,			-- Set true if you want the bar to flash
					order	= 2,				-- Order of the bar in relation to other Proc bars
					cd		= false				-- Set true if you want to show the cooldown bar.
				}

Debuffs:
SquawkAndAwe.defaults.char.bars.debuffs.Moonfire	= {
					show	= true,
					color	= {r=0.5, g=0, b=1, a=0.9},
					tick	= true,				-- Set true if you want tick bars for this spell
					order	= 1,
				}

CC:
SquawkAndAwe.defaults.char.bars.cc.Roots	= {
					show	= true,
					color	= {r=0.38, g=0.2, b=0.08, a=0.9},
					order	= 1,
				}

Abilities:
SquawkAndAwe.defaults.char.bars.abilities.Force	= {
					show	= true,
					color	= {r=0, g=1, b=0, a=0.9},
					dur		= true,				-- Set true if you want to show the duration as well as cooldown
					order	= 3,
				}

--------------------------------------------------------------------------------

Step 4: There is no step four. Load up the addon, your custom bar should show up now.
--]]

--function SquawkAndAwe:LoadCustomBars()
--------------------------------------------------------------------------------
------------ Place all spell declarations (Step Two) below this line.-----------
--------------------------------------------------------------------------------
SquawkAndAwe.combat.trinkets.heroiccharred	= {
	id			= 75473,
	itemid		= 54588,
	name		= GetSpellInfo(75473),
	itemname	= GetItemInfo(54588),
	color 		= {r=1, g=0.8, b=0.32, a=0.9},
	cd 			= 45,
	shortname	= "Charred Scale"}

SquawkAndAwe.combat.procs.Frenzy	= {
	id			= 48391,
	name		= GetSpellInfo(48391)}
	
SquawkAndAwe.combat.procs.RepRing	= {
	id 			= 72416,
	name		= GetSpellInfo(72416),
	cd			= 60}

SquawkAndAwe.combat.procs.Lightweave	= {
	id			= 55640,
	name		= GetSpellInfo(55640),
	cd 			= 60}
	
SquawkAndAwe.combat.abilities.Starsurge	= {
	id			= 78674,
	name		= GetSpellInfo(78674)}
	
--------------------------------------------------------------------------------
--------- Place all settings declarations (Step Three) below this line.---------
--------------------------------------------------------------------------------

-- Remember, since Heroic Charred Twilight Scale is a trinket, it isn't included 
-- in Step Three

SquawkAndAwe.defaults.char.bars.procs.Frenzy	= {	-- Note how for both Step Two and Step Three the name chosen is 'Frenzy'
	show	= true,
	color	= {r=0.6,	g=0.6,	b=1,	a=0.9},
	sound	= "None",
	flash   = true,
	order	= 7}

SquawkAndAwe.defaults.char.bars.procs.RepRing	= {
	show	= true,
	color	= {r=0.6,	g=0.6,	b=1,	a=0.9},
	sound	= "None",
	flash   = true,
	order	= 8,
	cd		= true}

SquawkAndAwe.defaults.char.bars.procs.Lightweave	= {
	show	= true,
	color	= {r=1.2,g=1.2,	b=1.2, a=0.9},
	sound	= "None",
	flash   = true,
	order	= 9,
	cd		= true}
	
SquawkAndAwe.defaults.char.bars.abilities.Starsurge	= {
	show	= true,
	color	= {r=0, g=0.5, b=1, a=0.9},
	order	= 6}

--end
